package com.ruoyi.inventory.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.inventory.domain.HealthcareInventoryDrugentry;

/**
 * 药品入库记录Service接口
 * 
 * @author 蒋松霖
 * @date 2024-09-27
 */
public interface IHealthcareInventoryDrugentryService 
{
    /**
     * 查询药品入库记录
     * 
     * @param id 药品入库记录主键
     * @return 药品入库记录
     */
    public AjaxResult selectHealthcareInventoryDrugentryById(Long id );

    /**
     * 查询药品入库记录列表
     * 
     * @param healthcareInventoryDrugentry 药品入库记录
     * @return 药品入库记录集合
     */
    public List<HealthcareInventoryDrugentry> selectHealthcareInventoryDrugentryList(HealthcareInventoryDrugentry healthcareInventoryDrugentry);

    /**
     * 新增药品入库记录
     * 
     * @param healthcareInventoryDrugentry 药品入库记录
     * @return 结果
     */
    public int insertHealthcareInventoryDrugentry(HealthcareInventoryDrugentry healthcareInventoryDrugentry);

    /**
     * 修改药品入库记录
     * 
     * @param healthcareInventoryDrugentry 药品入库记录
     * @return 结果
     */
    public int updateHealthcareInventoryDrugentry(HealthcareInventoryDrugentry healthcareInventoryDrugentry);

    /**
     * 批量删除药品入库记录
     * 
     * @param ids 需要删除的药品入库记录主键集合
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugentryByIds(Long[] ids);

    /**
     * 删除药品入库记录信息
     * 
     * @param id 药品入库记录主键
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugentryById(Long id);

    int saveHealthcareInventoryDrugentry(HealthcareInventoryDrugentry healthcareInventoryDrugentry);
}
